#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['smartmeter']

package_data = \
{'': ['*']}

install_requires = \
['requests >=2.24.0,<3.0.0', 'lxml >=4.6.3,<5.0.0']

extras_require = \
{'test': ['pytest ==5.4.3',
          'pytest-cov ==2.10.0',
          'pytest-asyncio >=0.14.0,<0.15.0',
          'mypy ==0.812',
          'flake8 >=3.8.3,<4.0.0',
          'black ==20.8b1',
          'lxml-stubs']}

setup(name='vienna-smartmeter',
      version='0.1.0',
      description='Unofficial Python wrapper for the Wiener Netze Smart Meter private API',
      author='Platysma',
      author_email=None,
      url='https://github.com/Platysma/vienna-smartmeter',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.5',
     )
